@@ -6,7 +6,7 @@ from .config import current_role
 from .tasks import restart
 from .utils import upload_dir
 
-__all__ = ['update', 'install', 'install_master', 'install_agent', 'apply', 'force']
+__all__ = ['update', 'update_configs', 'install', 'install_master', 'install_agent', 'apply', 'force']
 
 files_path = os.path.join(os.path.dirname(__file__), 'files')
 
@@ -29,6 +29,14 @@ def update():
     with cd('/etc/puppet'):
         sudo('librarian-puppet install --path /etc/puppet/vendor')
 
+    # Install custom manifests if they exist
+    if os.path.exists('manifests/site.pp') and os.path.isfile('manifests/site.pp'):
+        upload_dir('manifests/', '/etc/puppet/manifests', use_sudo=True)
+    # Otherwise generate basic site.pp
+    else:
+        sudo('mkdir -p /etc/puppet/manifests')
+        put(StringIO('include "roles::$role"\n'), '/etc/puppet/manifests/site.pp', use_sudo=True)
+
 @task
 def update_configs():
     """
@@ -46,11 +54,6 @@ def update_configs():
     }, use_sudo=True)
     put(os.path.join(files_path, 'puppet/auth.conf'), '/etc/puppet/auth.conf', use_sudo=True)
 
-    # Install manifest
-    sudo('mkdir -p /etc/puppet/manifests')
-    put(StringIO('include "roles::$role"\n'), '/etc/puppet/manifests/site.pp', use_sudo=True)
-
-
 @task
 def install():
     """
